/*ULMBDO02.C****************************************************************

File:                         ULMBDO02.C

Library Call Demonstrated:		cbDBitOut() for MetraBus Cards

Purpose:						Writes a bit to a digital output port.

Demonstration:					Writes a value to FIRSTPORTA 

Other Library Calls:			cbErrHandling()

Special Requirements:			MetraBus digital output card must be installed


Copyright (c) 1995-2002, Measurement Computing Corp.
All Rights Reserved.
***************************************************************************/


/* Include files */
#include <math.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <conio.h>
#include <time.h>
#include <windows.h>
#include ".\cbw.h"


/* Prototypes */
void ClearScreen (void);
void GetTextCursor (int *x, int *y);
void MoveCursor (int x, int y);
BOOL ask();
int getNewBoardNumber(int col, int row);

double timetic=(double)(CLOCKS_PER_SEC);


char cfg_name[21]="circle1.cfg";



double harm_delay(long delay0) {

   long j;
   double sum;


      sum=0.0;

      for (j=1; j<=delay0; j++) {
         sum=sum+1.0/(double)(j);
      } /* for j */

      return(sum);

} /* harm_delay */


void main() {

	/* Variable Declarations */

	int Row, Col;
	int BoardNum = 0;
	int ULStat = 0;
	int PortNum, Direction;
	WORD DataValue;
	int BitLevel;
	int BitNum;
	WORD BitValue;
	int hilo;
	float    RevLevel = (float)CURRENTREVNUM;
	char s[32];  // string for user input

	long i,j, n;

	double pi1 = 3.141592653589793238;



	/* Declare UL Revision Level */

	ULStat = cbDeclareRevision(&RevLevel);

	/* Initiate error handling

		Parameters:
			PRINTALL :all warnings and errors encountered will be printed
			DONTSTOP :program will continue even if error occurs.
					 Note that STOPALL and STOPFATAL are only effective in
					 Windows applications, not Console applications.
   */

	cbErrHandling(PRINTALL, DONTSTOP);

	/* set up the display screen */

	/*
	ClearScreen();
	*/


	/* specify the port number */

	PortNum = FIRSTPORTA;
	Direction = DIGITALOUT;
	ULStat = cbDConfigPort(BoardNum, PortNum, Direction);


	/* get a user value to write to the port */

	DataValue = 8;


	/* write BitValue to BitNum of FIRSTPORTA

		Parameters:
			BoardNum    :the number used by CB.CFG to describe this board
			PortNum     :must be FIRSTPORTA
			BitNum      :the number of the bit to be set to BitValue
			BitValue    :the value written to the port   */


	for (j = 0; j <= 7; j++) {

	   BitNum = j;
	   BitValue = 0;

	   ULStat = cbDBitOut(BoardNum, PortNum, BitNum, BitValue);

    } /* for j */


    } /* End program */





/***************************************************************************
*
* Name:      reportCurrentBoardNumber(int boardNum)
* Arguments: boardNum - boardNumber
* Returns:   nothing
*
* Queries user and returns the selected board number
*
***************************************************************************/
void reportCurrentBoardNumber(int boardNum)
{
    int c,r;
	GetTextCursor(&c,&r);
	MoveCursor(0,2);
	printf("Currently selected board number is %i.   ",boardNum);
	MoveCursor(c,r);
}

/***************************************************************************
*
* Name:      getNewBoardNumber(int col, int row)
* Arguments: screen position: col = column, row
* Returns:   number from 0 to 63
*
* Queries user and returns the selected board number
*
***************************************************************************/
int getNewBoardNumber(int col, int row)
{
	int bdNum = -1;
	char s[32];
	do
	{
        MoveCursor (col, row);
		printf("Enter new board number -->                        ");
        MoveCursor (col+32, row);
		gets(s);
		sscanf(s,"%i",&bdNum);
	}
	while ((bdNum<0) || (bdNum>64));
	return bdNum;
}

/***************************************************************************
*
* Name:      ask(char *question)
* Arguments: char *question
* Returns:   TRUE if user responds y, FALSE otherwise
*
* Queries user for yes or no response
*
***************************************************************************/

BOOL ask(char *question)
{
   BOOL retval = FALSE;
   char response;
   printf(question);
   response = (char)getchar();
   switch (response)
   {
     case 'y' :
     case 'Y' : retval = TRUE;
   }
   printf("\n\n");
   return retval;
}


/***************************************************************************
*
* Name:      ClearScreen
* Arguments: ---
* Returns:   ---
*
* Clears the screen.
*
***************************************************************************/

#define BIOS_VIDEO   0x10

void
ClearScreen (void)
{
	COORD coordOrg = {0, 0};
	DWORD dwWritten = 0;
	HANDLE hConsole = GetStdHandle(STD_OUTPUT_HANDLE);
	if (INVALID_HANDLE_VALUE != hConsole)
		FillConsoleOutputCharacter(hConsole, ' ', 80 * 50, coordOrg, &dwWritten);

	MoveCursor(0, 0);

    return;
}


/***************************************************************************
*
* Name:      MoveCursor
* Arguments: x,y - screen coordinates of new cursor position
* Returns:   ---
*
* Positions the cursor on screen.
*
***************************************************************************/


void
MoveCursor (int x, int y)
{
	HANDLE hConsole = GetStdHandle(STD_OUTPUT_HANDLE);

	if (INVALID_HANDLE_VALUE != hConsole)
	{
		COORD coordCursor;
		coordCursor.X = (short)x;
		coordCursor.Y = (short)y;
		SetConsoleCursorPosition(hConsole, coordCursor);
	}

    return;
}


/***************************************************************************
*
* Name:      GetTextCursor
* Arguments: x,y - screen coordinates of new cursor position
* Returns:   *x and *y
*
* Returns the current (text) cursor position.
*
***************************************************************************/

void
GetTextCursor (int *x, int *y)
{
	HANDLE hConsole = GetStdHandle(STD_OUTPUT_HANDLE);
	CONSOLE_SCREEN_BUFFER_INFO csbi;

	*x = -1;
	*y = -1;
	if (INVALID_HANDLE_VALUE != hConsole)
	{
		GetConsoleScreenBufferInfo(hConsole, &csbi);
		*x = csbi.dwCursorPosition.X;
		*y = csbi.dwCursorPosition.Y;
	}

    return;
}





